@@ -5,7 +5,6 @@
 #include "Utils.h"
 #include "TukeyDepth.h"
 #include "armadillo"
-#include <omp.h>
 
 namespace Depth
 {
@@ -23,8 +22,8 @@ namespace Depth
  arma::vec MahalanobisDepth(const arma::mat& X, const arma::mat& Y, const arma::mat& cov, const arma::rowvec& mean, int threads);
 
 	// Projection Depth
-	arma::vec ProjectionDepth(const arma::mat& X, size_t nproj, double seed, int threads);
-	arma::vec ProjectionDepth(const arma::mat& X, const arma::mat& Y, size_t nproj, double seed, int threads);
+	arma::vec ProjectionDepth(const arma::mat& X, size_t nproj, int threads);
+	arma::vec ProjectionDepth(const arma::mat& X, const arma::mat& Y, size_t nproj, int threads);
 
   arma::vec TukeyDepth(const arma::mat& X, const arma::mat& Y,bool exact, int threads);
 }
